@@ -54,11 +54,11 @@ const READ_ONLY_ANNO = "placesInternal/READ_ONLY";
 const LMANNO_FEEDURI = "livemark/feedURI";
 const LMANNO_SITEURI = "livemark/siteURI";
 
-//@line 58 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/toolkit/components/places/src/utils.js"
+//@line 58 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/toolkit/components/places/src/utils.js"
 // On Mac OSX, the transferable system converts "\r\n" to "\n\n", where we
 // really just want "\n".
 const NEWLINE= "\n";
-//@line 65 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/toolkit/components/places/src/utils.js"
+//@line 65 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/toolkit/components/places/src/utils.js"
 
 function QI_node(aNode, aIID) {
   var result = null;
@@ -1450,8 +1450,17 @@ var PlacesUtils = {
 
       addGenericProperties(bNode, node);
 
-      if (self.nodeIsURI(bNode))
+      if (self.nodeIsURI(bNode)) {
+        // Check for url validity, since we can't halt while writing a backup.
+        // This will throw if we try to serialize an invalid url and it does
+        // not make sense saving a wrong or corrupt uri node.
+        try {
+          self._uri(bNode.uri);
+        } catch (ex) {
+          return;
+        }
         addURIProperties(bNode, node);
+      }
       else if (self.nodeIsContainer(bNode))
         addContainerProperties(bNode, node);
       else if (self.nodeIsSeparator(bNode))
